@@ -36,7 +36,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.11.1'; # VERSION
+our $VERSION = 'v0.11.2'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -540,7 +540,7 @@ sub configure {
         [ 'Test::Version' => {          # All modules have version.
             finder    => "$name/Manifest::Read/InstallModules",
                 # REQUIRE: Dist::Zilla::Plugin::Manifest::Read v0.4.0 # want `/InstallModules`.
-            is_strict => 0,           # Strict version test fails in trial releases.
+            is_strict => 0,             # Strict version test fails in trial releases.
         } ],
 
         #   I would like to set `Test::Version`'s `is_strict` option to `1`, but it will fail for
@@ -568,7 +568,7 @@ sub configure {
 
         # POD
 
-        [ 'PodSyntaxTests'   ],     # `Dist-Zilla`-bundled test, uses `Test::pod`.
+        [ 'PodSyntaxTests'   ],     # `Dist-Zilla`-bundled test, uses `Test::Pod`.
 
         [ 'PodCoverageTests' ],     # `Dist-Zilla`-bundled test, uses `Pod::Coverage::TrustPod`.
 
@@ -944,7 +944,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.11.1, released on 2015-11-06 08:22 UTC.
+Version v0.11.2, released on 2015-11-06 22:24 UTC.
 
 =head1 WHAT?
 
